API Reference
=============

.. automodule:: metasyn
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   metasyn.distribution
   metasyn.schema
   metasyn.demo

Submodules
----------

metasyn.metaframe module
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.metaframe
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.provider module
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.provider
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.var module
^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.var
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.testutils module
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.testutils
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.validation module
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.validation
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.privacy module
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.privacy
   :members:
   :undoc-members:
   :show-inheritance:
